pub struct CastOptions<'a> {
pub safe: bool,
pub format_options: FormatOptions<'a>,
}Expand description
CastOptions provides a way to override the default cast behaviors
Fields
safe: boolhow to handle cast failures, either return NULL (safe=true) or return ERR (safe=false)
format_options: FormatOptions<'a>Formatting options when casting from temporal types to string