pub enum TryLockError {
Error(Error),
WouldBlock,
}Expand description
An enumeration of possible errors which can occur while trying to acquire a lock
from the try_lock method and try_lock_shared method on a File.
Variants
Error(Error)
The lock could not be acquired due to an I/O error on the file. The standard library will
not return an ErrorKind::WouldBlock error inside TryLockError::Error
WouldBlock
The lock could not be acquired at this time because it is held by another handle/process.